
## Decide if the RSS needs to be updated and the newsletter being sent.

We could have a configuration field where the user decides when the
email/rss are generated. For example for the weekly event, the local newsletter
will be created on Mondays, but if the sending event is meant to be on
Thursdays, then the user can change the local newsletter manually before they
are sent.

Based on
[1](https://www.wordstream.com/blog/ws/2014/09/04/best-time-to-send-email-campaign)
and [2](https://sleeknote.com/blog/best-time-to-send-email), the default
notifications day should be on Thursdays.

This step will output a list of articles that need to be processed.
